/**
 * Copyright (C) 2011 Ovea <dev@ovea.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ovea.cometd;

import com.google.common.util.concurrent.ThreadFactoryBuilder;
import org.cometd.server.BayeuxServerImpl;

import java.util.concurrent.Executor;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;

/**
 * @author Mathieu Carbou (mathieu.carbou@gmail.com)
 */
public class WebSocketTransport extends org.cometd.websocket.server.WebSocketTransport {
    public WebSocketTransport(BayeuxServerImpl bayeux) {
        super(bayeux);
    }

    @Override
    protected ScheduledExecutorService newScheduledExecutor() {
        return Executors.newSingleThreadScheduledExecutor(new ThreadFactoryBuilder()
            .setNameFormat("WebSocketTransport-Scheduler-%1s")
            .build());
    }

    @Override
    protected Executor newExecutor() {
        int size = getOption(THREAD_POOL_MAX_SIZE, 64);
        return Executors.newFixedThreadPool(size, new ThreadFactoryBuilder()
            .setNameFormat("WebSocketTransport-Thread-%1s")
            .build());
    }

    @Override
    public String toString() {
        return org.cometd.websocket.server.WebSocketTransport.class.getSimpleName();
    }
}
